==> react-mapfilter-0.0.2.tgz: package/es5/containers/index_route.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var React = require('react');

var _require = require('react-redux'),
    connect = _require.connect;

var _require2 = require('redux'),
    bindActionCreators = _require2.bindActionCreators;

var Match = require('react-router/Match').default;
var Redirect = require('react-router/Redirect').default;
var Miss = require('react-router/Miss').default;
var assign = require('object-assign');

var FilterContainer = require('./filter_container');
var TopBar = require('./top_bar');
var actionCreators = require('../action_creators');

var _require3 = require('../util/filter_helpers'),
    decodeFilter = _require3.decodeFilter;

var MapContainer = require('./map_container');
var ReportContainer = require('./report_container');
var ImageContainer = require('./image_container');
var FeatureModal = require('../components/feature_modal');
var MatchModal = require('../components/match_modal');

var styles = {
  outer: {
    position: 'fixed',
    top: 0,
    right: 0,
    bottom: 0,
    left: 0,
    display: 'flex',
    flexDirection: 'column',
    fontFamily: 'Roboto, sans-serif',
    WebkitFontSmoothing: 'antialiased',
    fontSize: 15,
    lineHeight: '24px'
  },
  inner: {
    display: 'flex',
    flex: 1
  }
};

var IndexRoute = function (_React$Component) {
  _inherits(IndexRoute, _React$Component);

  function IndexRoute() {
    var _ref;

    var _temp, _this, _ret;

    _classCallCheck(this, IndexRoute);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = IndexRoute.__proto__ || Object.getPrototypeOf(IndexRoute)).call.apply(_ref, [this].concat(args))), _this), _this.closeModal = function () {
      var _this$props = _this.props,
          router = _this$props.router,
          location = _this$props.location;

      var newLocation = assign({}, location, {
        pathname: '/' + location.pathname.split('/')[1]
      });
      router.transitionTo(newLocation);
    }, _this.openFeatureModal = function (id) {
      var _this$props2 = _this.props,
          router = _this$props2.router,
          location = _this$props2.location;

      var newLocation = assign({}, location, {
        pathname: '/' + location.pathname.split('/')[1] + '/features/' + id
      });
      router.transitionTo(newLocation);
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  _createClass(IndexRoute, [{
    key: 'componentWillMount',


    // Read the filter and map position from the URL on first load
    value: function componentWillMount() {
      var _props = this.props,
          filters = _props.filters,
          query = _props.location.query,
          updateFilter = _props.updateFilter,
          router = _props.router;

      // If `filter` is not set, try to read it from the URL query parameter
      // and update the application state.

      if (!filters && query.filter) {
        try {
          updateFilter(decodeFilter(query.filter));
        } catch (e) {
          console.warn('Could not parse filter from URL, reseting filter');
          // Remove an invalid filter from the URL.
          var newQuery = assign({}, query, { filter: undefined });
          var newLocation = assign({}, this.props.location, newQuery);
          router.replaceWith(newLocation);
        }
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      var location = this.props.location;

      var sections = ['map', 'photos', 'report'];
      var tabs = sections.map(function (section) {
        return {
          active: section === location.pathname.split('/')[1],
          id: section,
          link: '/' + section
        };
      });

      return React.createElement(
        'div',
        { style: styles.outer },
        React.createElement(TopBar, { tabs: tabs }),
        React.createElement(
          'div',
          { style: styles.inner },
          React.createElement(FilterContainer, null),
          React.createElement(Match, { pattern: '/map', render: function render(matchProps) {
              return React.createElement(MapContainer, _extends({}, matchProps, { onMarkerClick: _this2.openFeatureModal }));
            } }),
          React.createElement(Match, { pattern: '/photos', render: function render(matchProps) {
              return React.createElement(ImageContainer, _extends({}, matchProps, { onImageClick: _this2.openFeatureModal }));
            } }),
          React.createElement(Match, { pattern: '/report', component: ReportContainer })
        ),
        React.createElement(MatchModal, {
          pattern: '/:section(map|photos|report)/features/:id',
          render: function render(matchProps) {
            return React.createElement(FeatureModal, {
              id: matchProps.params.id,
              onCloseClick: _this2.closeModal
            });
          } }),
        React.createElement(Miss, { render: function render() {
            return React.createElement(Redirect, { to: '/map' });
          } })
      );
    }
  }]);

  return IndexRoute;
}(React.Component);

module.exports = connect(function (state) {
  return {
    filters: state.filters
  };
}, function (dispatch) {
  return bindActionCreators(actionCreators, dispatch);
})(IndexRoute);

==> react-mapfilter-0.1.0.tgz: package/es5/containers/index_route.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var React = require('react');

var _require = require('react-redux'),
    connect = _require.connect;

var _require2 = require('redux'),
    bindActionCreators = _require2.bindActionCreators;

var Match = require('react-router/Match').default;
var Redirect = require('react-router/Redirect').default;
var Miss = require('react-router/Miss').default;
var assign = require('object-assign');

var FilterContainer = require('./filter_container');
var TopBar = require('./top_bar');
var actionCreators = require('../action_creators');

var _require3 = require('../util/filter_helpers'),
    decodeFilter = _require3.decodeFilter;

var FilterConfigurator = require('../components/filter_configurator');
var MapContainer = require('./map_container');
var ReportContainer = require('./report_container');
var ImageContainer = require('./image_container');
var FeatureModal = require('../components/feature_modal');
var MatchModal = require('../components/match_modal');

var styles = {
  outer: {
    position: 'fixed',
    top: 0,
    right: 0,
    bottom: 0,
    left: 0,
    display: 'flex',
    flexDirection: 'column',
    fontFamily: 'Roboto, sans-serif',
    WebkitFontSmoothing: 'antialiased',
    fontSize: 15,
    lineHeight: '24px'
  },
  inner: {
    display: 'flex',
    flex: 1
  }
};

var IndexRoute = function (_React$Component) {
  _inherits(IndexRoute, _React$Component);

  function IndexRoute() {
    var _ref;

    var _temp, _this, _ret;

    _classCallCheck(this, IndexRoute);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = IndexRoute.__proto__ || Object.getPrototypeOf(IndexRoute)).call.apply(_ref, [this].concat(args))), _this), _this.closeModal = function () {
      var _this$props = _this.props,
          router = _this$props.router,
          location = _this$props.location;

      var newLocation = assign({}, location, {
        pathname: '/' + location.pathname.split('/')[1]
      });
      router.transitionTo(newLocation);
    }, _this.openFeatureModal = function (id) {
      var _this$props2 = _this.props,
          router = _this$props2.router,
          location = _this$props2.location;

      var newLocation = assign({}, location, {
        pathname: '/' + location.pathname.split('/')[1] + '/features/' + id
      });
      router.transitionTo(newLocation);
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  _createClass(IndexRoute, [{
    key: 'componentWillMount',


    // Read the filter and map position from the URL on first load
    value: function componentWillMount() {
      var _props = this.props,
          filters = _props.filters,
          query = _props.location.query,
          updateFilter = _props.updateFilter,
          router = _props.router;

      // If `filter` is not set, try to read it from the URL query parameter
      // and update the application state.

      if (!filters && query.filter) {
        try {
          updateFilter(decodeFilter(query.filter));
        } catch (e) {
          console.warn('Could not parse filter from URL, reseting filter');
          // Remove an invalid filter from the URL.
          var newQuery = assign({}, query, { filter: undefined });
          var newLocation = assign({}, this.props.location, newQuery);
          router.replaceWith(newLocation);
        }
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      var location = this.props.location;

      var sections = ['map', 'photos', 'report'];
      var tabs = sections.map(function (section) {
        return {
          active: section === location.pathname.split('/')[1],
          id: section,
          link: '/' + section
        };
      });

      return React.createElement(
        'div',
        { style: styles.outer },
        React.createElement(TopBar, { tabs: tabs }),
        React.createElement(
          'div',
          { style: styles.inner },
          React.createElement(FilterContainer, { location: location }),
          React.createElement(Match, { pattern: '/map', render: function render(matchProps) {
              return React.createElement(MapContainer, _extends({}, matchProps, { onMarkerClick: _this2.openFeatureModal }));
            } }),
          React.createElement(Match, { pattern: '/photos', render: function render(matchProps) {
              return React.createElement(ImageContainer, _extends({}, matchProps, { onImageClick: _this2.openFeatureModal }));
            } }),
          React.createElement(Match, { pattern: '/report', component: ReportContainer })
        ),
        React.createElement(MatchModal, {
          pattern: '/:section(map|photos|report)/features/:id',
          render: function render(matchProps) {
            return React.createElement(FeatureModal, {
              id: matchProps.params.id,
              onCloseClick: _this2.closeModal
            });
          } }),
        React.createElement(MatchModal, {
          pattern: '/:section(map|photos|report)/settings/filters',
          render: function render(matchProps) {
            return React.createElement(FilterConfigurator, {
              onCloseClick: _this2.closeModal
            });
          } }),
        React.createElement(Miss, { render: function render() {
            return React.createElement(Redirect, { to: '/map' });
          } })
      );
    }
  }]);

  return IndexRoute;
}(React.Component);

module.exports = connect(function (state) {
  return {
    filters: state.filters
  };
}, function (dispatch) {
  return bindActionCreators(actionCreators, dispatch);
})(IndexRoute);
